NodeType

Enum NodeType 

pub enum NodeType {
    Object(Box<Object>),
    ObjectType(Box<ObjectType>),
    ReferenceType(Box<ReferenceType>),
    Variable(Box<Variable>),
    VariableType(Box<VariableType>),
    View(Box<View>),
    DataType(Box<DataType>),
    Method(Box<Method>),
}
The NodeType enum enumerates the different OPC-UA node classes.

Variants



Object(Box<Object>)

Objects are general structural nodes without special meaning.



ObjectType(Box<ObjectType>)

Object types define properties of object nodes.



ReferenceType(Box<ReferenceType>)

Reference types define properties of references.



Variable(Box<Variable>)

Variables are nodes with a current value that can be stored historically.



VariableType(Box<VariableType>)

Variable types define properties of variable nodes.



View(Box<View>)

Views are pre-defined subsets of the address space.



DataType(Box<DataType>)

Data types define different types used by variables.



Method(Box<Method>)

Methods are nodes that can be called with the Call service.

Implementations

Source

impl NodeType

pub fn as_node<'a>(&'a self) -> &'a (dyn Node + 'a)

Get a reference to this as dyn Node.

pub fn as_mut_node(&mut self) -> &mut dyn Node

Get a reference to this as mut dyn Node.

pub fn node_class(&self) -> NodeClass

Returns the NodeClass of this NodeType.