Base

Struct Base 

pub struct Base { /* private fields */ }
Base node class contains the attributes that all other kinds of nodes need. Part 3, diagram B.4

Implementations

Source

impl Base

pub fn new( node_class: NodeClass, node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, ) -> Base

Create a new base node.

pub fn new_full( node_id: NodeId, node_class: NodeClass, browse_name: QualifiedName, display_name: LocalizedText, description: Option<LocalizedText>, write_mask: Option<u32>, user_write_mask: Option<u32>, ) -> Self

Create a new base node with all attributes, may change if new attributes are added to the OPC-UA standard.

pub fn is_valid(&self) -> bool

Get whether this base node is valid.

pub fn set_node_id(&mut self, node_id: NodeId)

Set the node ID of this node.

pub fn set_browse_name(&mut self, browse_name: impl Into<QualifiedName>)

Set the browse name of this node.