pub struct DataType { /* private fields */ }Expand description
A DataType is a type of node within the AddressSpace.
Implementations
Sourceimpl DataType
impl DataType
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
is_abstract: bool,
) -> DataType
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, is_abstract: bool, ) -> DataType
Create a new data type.
Sourcepub fn new_full(
base: Base,
is_abstract: bool,
data_type_definition: Option<DataTypeDefinition>,
) -> Self
pub fn new_full( base: Base, is_abstract: bool, data_type_definition: Option<DataTypeDefinition>, ) -> Self
Create a new data type with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: DataTypeAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: DataTypeAttributes, ) -> Result<Self, FromAttributesError>
Create a new data type from DataTypeAttributes.
Sourcepub fn is_abstract(&self) -> bool
pub fn is_abstract(&self) -> bool
Get the IsAbstract attribute for this data type.
Sourcepub fn set_is_abstract(&mut self, is_abstract: bool)
pub fn set_is_abstract(&mut self, is_abstract: bool)
Set the IsAbstract attribute for this data type.
Sourcepub fn set_data_type_definition(
&mut self,
data_type_definition: Option<DataTypeDefinition>,
)
pub fn set_data_type_definition( &mut self, data_type_definition: Option<DataTypeDefinition>, )
Set the data type definition of this data type.
Sourcepub fn data_type_definition(&self) -> Option<&DataTypeDefinition>
pub fn data_type_definition(&self) -> Option<&DataTypeDefinition>
Get the data type definition of this data type.