pub struct Method { /* private fields */ }Expand description
A Method is a type of node within the AddressSpace.
Implementations
Sourceimpl Method
impl Method
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
executable: bool,
user_executable: bool,
) -> Method
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, executable: bool, user_executable: bool, ) -> Method
Create a new method.
Sourcepub fn new_full(base: Base, executable: bool, user_executable: bool) -> Self
pub fn new_full(base: Base, executable: bool, user_executable: bool) -> Self
Create a new method with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: MethodAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: MethodAttributes, ) -> Result<Self, FromAttributesError>
Create a new method from MethodAttributes.
Sourcepub fn executable(&self) -> bool
pub fn executable(&self) -> bool
Get whether this method is executable.
Sourcepub fn set_executable(&mut self, executable: bool)
pub fn set_executable(&mut self, executable: bool)
Set whether this method is executable.
Sourcepub fn user_executable(&self) -> bool
pub fn user_executable(&self) -> bool
Get whether this method is executable by the current user by default.
Sourcepub fn set_user_executable(&mut self, user_executable: bool)
pub fn set_user_executable(&mut self, user_executable: bool)
Set whether this method is executable by the current user by default.