MethodBuilder

Struct MethodBuilder 

pub struct MethodBuilder { /* private fields */ }
A builder for constructing a node of same name. This can be used as an easy way to create a node and the references it has to another node in a simple fashion.

Implementations

Source

impl MethodBuilder

pub fn new<T, S>(node_id: &NodeId, browse_name: T, display_name: S) -> Self

Creates a builder for a node. All nodes are required to su

pub fn get_node_id(&self) -> &NodeId

Get the node ID of the node being built.

pub fn is_valid(&self) -> bool

Tests that the builder is in a valid state to build or insert the node.

pub fn description<V>(self, description: V) -> Self
where V: Into<LocalizedText>,

Sets the description of the node

pub fn reference<T>( self, node_id: T, reference_type_id: ReferenceTypeId, reference_direction: ReferenceDirection, ) -> Self
where T: Into<NodeId>,

Adds a reference to the node

pub fn organizes<T>(self, organizes_id: T) -> Self
where T: Into<NodeId>,

Indicates this node organizes another node by its id.

pub fn organized_by<T>(self, organized_by_id: T) -> Self
where T: Into<NodeId>,

Indicates this node is organised by another node by its id

pub fn build(self) -> Method

Yields a built node. This function will panic if the node is invalid. Note that calling this function discards any references for the node, so there is no purpose in adding references if you intend to call this method.

pub fn insert(self, address_space: &mut impl NodeInsertTarget) -> bool

Inserts the node into the address space, including references. This function will panic if the node is in an invalid state.

Source

impl MethodBuilder

pub fn component_of<T>(self, component_of_id: T) -> Self
where T: Into<NodeId>,

Add an inverse HasComponent reference to the given node.

pub fn has_component<T>(self, has_component_id: T) -> Self
where T: Into<NodeId>,

Add a HasComponent reference to the given node.

Source

impl MethodBuilder

pub fn generates_event<T>(self, event_type: T) -> Self
where T: Into<NodeId>,

Add a GeneratesEvent reference to the given event type.

Source

impl MethodBuilder

pub fn output_args( self, address_space: &mut impl NodeInsertTarget, node_id: &NodeId, arguments: &[Argument], ) -> Self

Specify output arguments from the method. This will create an OutputArguments variable child of the method which describes the out parameters.

pub fn input_args( self, address_space: &mut impl NodeInsertTarget, node_id: &NodeId, arguments: &[Argument], ) -> Self

Specify input arguments to the method. This will create an InputArguments variable child of the method which describes the in parameters.

pub fn executable(self, executable: bool) -> Self

Set whether this method is executable, meaning it can be called by users at all.

pub fn user_executable(self, executable: bool) -> Self

Set whether this method is executable by the current user. This value is usually modified by the server depending on the user asking for it.

pub fn write_mask(self, write_mask: WriteMask) -> Self

Set the write mask for this method.