pub struct Object { /* private fields */ }Expand description
An Object is a type of node within the AddressSpace.
Implementations
Sourceimpl Object
impl Object
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
event_notifier: EventNotifier,
) -> Object
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, event_notifier: EventNotifier, ) -> Object
Create a new object.
Sourcepub fn new_full(base: Base, event_notifier: EventNotifier) -> Self
pub fn new_full(base: Base, event_notifier: EventNotifier) -> Self
Create a new object with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: ObjectAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: ObjectAttributes, ) -> Result<Self, FromAttributesError>
Create a new object from ObjectAttributes.
Sourcepub fn event_notifier(&self) -> EventNotifier
pub fn event_notifier(&self) -> EventNotifier
Get the event notifier status of this object.
Sourcepub fn set_event_notifier(&mut self, event_notifier: EventNotifier)
pub fn set_event_notifier(&mut self, event_notifier: EventNotifier)
Set the event notifier status of this object.