pub struct ReferenceType { /* private fields */ }Expand description
A ReferenceType is a type of node within the AddressSpace.
Implementations
Sourceimpl ReferenceType
impl ReferenceType
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
inverse_name: Option<LocalizedText>,
symmetric: bool,
is_abstract: bool,
) -> ReferenceType
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, inverse_name: Option<LocalizedText>, symmetric: bool, is_abstract: bool, ) -> ReferenceType
Create a new reference type.
Sourcepub fn new_full(
base: Base,
symmetric: bool,
is_abstract: bool,
inverse_name: Option<LocalizedText>,
) -> Self
pub fn new_full( base: Base, symmetric: bool, is_abstract: bool, inverse_name: Option<LocalizedText>, ) -> Self
Create a new reference type with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: ReferenceTypeAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: ReferenceTypeAttributes, ) -> Result<Self, FromAttributesError>
Create a new reference type from ReferenceTypeAttributes.
Sourcepub fn set_symmetric(&mut self, symmetric: bool)
pub fn set_symmetric(&mut self, symmetric: bool)
Set whether this reference type is symmetric.
Sourcepub fn is_abstract(&self) -> bool
pub fn is_abstract(&self) -> bool
Get whether this reference type is abstract.
Sourcepub fn set_is_abstract(&mut self, is_abstract: bool)
pub fn set_is_abstract(&mut self, is_abstract: bool)
Get whether this reference type is abstract.
Sourcepub fn inverse_name(&self) -> Option<LocalizedText>
pub fn inverse_name(&self) -> Option<LocalizedText>
Get the inverse name of this reference type.
Sourcepub fn set_inverse_name(&mut self, inverse_name: LocalizedText)
pub fn set_inverse_name(&mut self, inverse_name: LocalizedText)
Set the inverse name of this reference type.