pub struct VariableType { /* private fields */ }Expand description
A VariableType is a type of node within the AddressSpace.
Implementations
Sourceimpl VariableType
impl VariableType
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
data_type: NodeId,
is_abstract: bool,
value_rank: i32,
) -> VariableType
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, data_type: NodeId, is_abstract: bool, value_rank: i32, ) -> VariableType
Create a new variable type node.
Sourcepub fn new_full(
base: Base,
data_type: NodeId,
is_abstract: bool,
value_rank: i32,
value: Option<DataValue>,
array_dimensions: Option<Vec<u32>>,
) -> Self
pub fn new_full( base: Base, data_type: NodeId, is_abstract: bool, value_rank: i32, value: Option<DataValue>, array_dimensions: Option<Vec<u32>>, ) -> Self
Create a new variable type with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: VariableTypeAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: VariableTypeAttributes, ) -> Result<Self, FromAttributesError>
Create a new variable type from VariableTypeAttributes.
Sourcepub fn set_data_type(&mut self, data_type: impl Into<NodeId>)
pub fn set_data_type(&mut self, data_type: impl Into<NodeId>)
Set the data type of this variable type.
Sourcepub fn is_abstract(&self) -> bool
pub fn is_abstract(&self) -> bool
Get the IsAbstract attribute for this variable type.
Sourcepub fn set_is_abstract(&mut self, is_abstract: bool)
pub fn set_is_abstract(&mut self, is_abstract: bool)
Set the IsAbstract attribute for this variable type.
Sourcepub fn value_rank(&self) -> i32
pub fn value_rank(&self) -> i32
Get the value rank of this variable type.
Sourcepub fn set_value_rank(&mut self, value_rank: i32)
pub fn set_value_rank(&mut self, value_rank: i32)
Set the value rank of this variable type.
Sourcepub fn array_dimensions(&self) -> Option<Vec<u32>>
pub fn array_dimensions(&self) -> Option<Vec<u32>>
Get the array dimensions of this type.
Sourcepub fn set_array_dimensions(&mut self, array_dimensions: &[u32])
pub fn set_array_dimensions(&mut self, array_dimensions: &[u32])
Set the array dimensions of this type.
Sourcepub fn set_value(&mut self, value: impl Into<Variant>)
pub fn set_value(&mut self, value: impl Into<Variant>)
Set the default value for instances of this type.
Sourcepub fn set_data_value(&mut self, value: DataValue)
pub fn set_data_value(&mut self, value: DataValue)
Set the default value for instances of this type to a full data value.