pub struct View { /* private fields */ }Expand description
A View is a type of node within the AddressSpace.
Implementations
Sourceimpl View
impl View
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
event_notifier: EventNotifier,
contains_no_loops: bool,
) -> View
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, event_notifier: EventNotifier, contains_no_loops: bool, ) -> View
Create a new view.
Sourcepub fn new_full(
base: Base,
event_notifier: EventNotifier,
contains_no_loops: bool,
) -> Self
pub fn new_full( base: Base, event_notifier: EventNotifier, contains_no_loops: bool, ) -> Self
Create a new view from the full Base node.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: ViewAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: ViewAttributes, ) -> Result<Self, FromAttributesError>
Create a new view from ViewAttributes.
Sourcepub fn event_notifier(&self) -> EventNotifier
pub fn event_notifier(&self) -> EventNotifier
Get the event notifier of this view.
Sourcepub fn set_event_notifier(&mut self, event_notifier: EventNotifier)
pub fn set_event_notifier(&mut self, event_notifier: EventNotifier)
Set the event notifier of this view.
Sourcepub fn contains_no_loops(&self) -> bool
pub fn contains_no_loops(&self) -> bool
Get the ContainsNoLoops attribute of this view.
Sourcepub fn set_contains_no_loops(&mut self, contains_no_loops: bool)
pub fn set_contains_no_loops(&mut self, contains_no_loops: bool)
Set the ContainsNoLoops attribute on this view.