AttributeQueryable

Trait AttributeQueryable 

pub trait AttributeQueryable: Copy {
    // Required methods
    fn get_attribute(
        &self,
        type_definition_id: &NodeId,
        browse_path: &[QualifiedName],
        attribute_id: AttributeId,
        index_range: &NumericRange,
    ) -> Variant;
    fn get_type(&self) -> NodeId;
}
Trait for something that can be queried for attribute values.

Implemented by dyn Event. Types passed to a content filter must implement this.

Required Methods

fn get_attribute( &self, type_definition_id: &NodeId, browse_path: &[QualifiedName], attribute_id: AttributeId, index_range: &NumericRange, ) -> Variant

Get an attribute value from the item.

fn get_type(&self) -> NodeId

Get the type definition of the item.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors