NodeInsertTarget

Trait NodeInsertTarget 

pub trait NodeInsertTarget {
    // Required method
    fn insert<'a>(
        &mut self,
        node: impl Into<NodeType>,
        references: Option<&'a [(&'a NodeId, &NodeId, ReferenceDirection)]>,
    ) -> bool;
}
Something a list of nodes can be inserted into. Implemented for AddressSpace in the server crate.

Required Methods

fn insert<'a>( &mut self, node: impl Into<NodeType>, references: Option<&'a [(&'a NodeId, &NodeId, ReferenceDirection)]>, ) -> bool

Insert a node with a list of references into a target.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors