pub struct DefaultTypeTree { /* private fields */ }Expand description
Type managing the types in an OPC-UA server. The server needs to know about all available types, to handle things like event filters, browse filtering, etc.
Each node manager is responsible for populating the type tree with its types.
Implementations
Sourceimpl DefaultTypeTree
impl DefaultTypeTree
Sourcepub fn add_type_node(
&mut self,
id: &NodeId,
parent: &NodeId,
node_class: NodeClass,
)
pub fn add_type_node( &mut self, id: &NodeId, parent: &NodeId, node_class: NodeClass, )
Add a new type to the type tree.
Sourcepub fn add_type_property(
&mut self,
id: &NodeId,
typ: &NodeId,
path: &[&QualifiedName],
node_class: NodeClass,
)
pub fn add_type_property( &mut self, id: &NodeId, typ: &NodeId, path: &[&QualifiedName], node_class: NodeClass, )
Add a new property to the type tree.
Sourcepub fn namespaces_mut(&mut self) -> &mut NamespaceMap
pub fn namespaces_mut(&mut self) -> &mut NamespaceMap
Get a mutable reference to the namespaces used by this type tree.
Sourcepub fn namespaces(&self) -> &NamespaceMap
pub fn namespaces(&self) -> &NamespaceMap
Get a reference to the namespaces used by this type tree.
Sourcepub fn get_all_children<'a>(&'a self, root: &'a NodeId) -> Vec<&'a NodeId>
pub fn get_all_children<'a>(&'a self, root: &'a NodeId) -> Vec<&'a NodeId>
Get a vector of all the descendants of the given root node.