pub struct ObjectType { /* private fields */ }Expand description
An ObjectType is a type of node within the AddressSpace.
Implementations
Sourceimpl ObjectType
impl ObjectType
Sourcepub fn new(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
display_name: impl Into<LocalizedText>,
is_abstract: bool,
) -> ObjectType
pub fn new( node_id: &NodeId, browse_name: impl Into<QualifiedName>, display_name: impl Into<LocalizedText>, is_abstract: bool, ) -> ObjectType
Create a new object type.
Sourcepub fn new_full(base: Base, is_abstract: bool) -> Self
pub fn new_full(base: Base, is_abstract: bool) -> Self
Create a new object type with all attributes, may change if new attributes are added to the OPC-UA standard.
Sourcepub fn from_attributes(
node_id: &NodeId,
browse_name: impl Into<QualifiedName>,
attributes: ObjectTypeAttributes,
) -> Result<Self, FromAttributesError>
pub fn from_attributes( node_id: &NodeId, browse_name: impl Into<QualifiedName>, attributes: ObjectTypeAttributes, ) -> Result<Self, FromAttributesError>
Create a new object type from ObjectTypeAttributes.
Sourcepub fn is_abstract(&self) -> bool
pub fn is_abstract(&self) -> bool
Get the IsAbstract attribute for this object type.
Sourcepub fn set_is_abstract(&mut self, is_abstract: bool)
pub fn set_is_abstract(&mut self, is_abstract: bool)
Set the IsAbstract attribute for this object type.